@@ -5,7 +5,7 @@ use 5.008004;
 use strict;
 use warnings;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use DateTime 0.1402;
 use DateTime::Calendar::Julian 0.04;
@@ -850,8 +850,12 @@ specification, and the year must not be signed.
 
 =head1 SUPPORT
 
-Support for this module is provided via the datetime@perl.org email
-list. See http://lists.perl.org/ for more details.
+Support for this module is provided via the F<datetime@perl.org> email
+list. See L<https://lists.perl.org/> for more details.
+
+Please report bugs to
+L<https://github.com/trwyant/perl-DateTime-Calendar-Christian/issues>, or
+in electronic mail to F<wyant@cpan.org>.
 
 =head1 AUTHOR
 
@@ -863,7 +867,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 Copyright (c) 2003 Eugene van der Pijll. All rights reserved.
 
-Copyright (C) 2016-2019 Thomas R. Wyant, III
+Copyright (C) 2016-2021 Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself; either the GNU General Public
